Tab

Struct Tab 

pub struct Tab {
Show 37 fields pub location: Location, pub location_ancestors: Vec<(Location, String)>, pub location_title: String, pub location_context_menu_point: Option<Point>, pub location_context_menu_index: Option<usize>, pub context_menu: Option<Point>, pub mode: Mode, pub scroll_opt: Option<AbsoluteOffset>, pub size_opt: Cell<Option<Size>>, pub content_height_opt: Cell<Option<f32>>, pub viewport_opt: Option<Rectangle>, pub item_view_size_opt: Cell<Option<Size>>, pub edit_location: Option<EditLocation>, pub edit_location_id: Id, pub history_i: usize, pub history: Vec<Location>, pub config: TabConfig, pub tb_config: TBConfig, pub thumb_config: ThumbCfg, pub sort_name: HeadingOptions, pub sort_direction: bool, pub gallery: bool, pub(crate) parent_item_opt: Option<Box<Item>>, pub(crate) items_opt: Option<Vec<Item>>, pub dnd_hovered: Option<(Location, Instant)>, pub(crate) scrollable_id: Id, select_focus: Option<usize>, select_range: Option<(usize, usize)>, clicked: Option<usize>, selected_clicked: bool, last_right_click: Option<usize>, search_context: Option<SearchContext>, date_time_formatter: DateTimeFormatter<YMDT>, time_formatter: DateTimeFormatter<T>, watch_drag: bool, window_id: Option<Id>, large_image_manager: LargeImageManager,
}

Fields

location: Locationlocation_ancestors: Vec<(Location, String)>location_title: Stringlocation_context_menu_point: Option<Point>location_context_menu_index: Option<usize>context_menu: Option<Point>mode: Modescroll_opt: Option<AbsoluteOffset>size_opt: Cell<Option<Size>>content_height_opt: Cell<Option<f32>>viewport_opt: Option<Rectangle>item_view_size_opt: Cell<Option<Size>>edit_location: Option<EditLocation>edit_location_id: Idhistory_i: usizehistory: Vec<Location>config: TabConfigtb_config: TBConfigthumb_config: ThumbCfgsort_name: HeadingOptionssort_direction: boolgallery: boolparent_item_opt: Option<Box<Item>>items_opt: Option<Vec<Item>>dnd_hovered: Option<(Location, Instant)>scrollable_id: Idselect_focus: Option<usize>select_range: Option<(usize, usize)>clicked: Option<usize>selected_clicked: boollast_right_click: Option<usize>search_context: Option<SearchContext>date_time_formatter: DateTimeFormatter<YMDT>time_formatter: DateTimeFormatter<T>watch_drag: boolwindow_id: Option<Id>large_image_manager: LargeImageManager

Implementations

Source

impl Tab

pub fn new( location: Location, config: TabConfig, tb_config: TBConfig, thumb_config: ThumbCfg, sorting_options: Option<&OrderMap<String, (HeadingOptions, bool), FxBuildHasher>>, scrollable_id: Id, window_id: Option<Id>, ) -> Self

pub fn title(&self) -> String

pub const fn items_opt(&self) -> Option<&Vec<Item>>

pub const fn items_opt_mut(&mut self) -> Option<&mut Vec<Item>>

pub fn set_items(&mut self, items: Vec<Item>)

pub fn cut_selected(&mut self)

pub fn refresh_cut(&mut self, locations: &[PathBuf])

pub fn selected_locations(&self) -> Vec<Location>

pub fn selected_delete_paths(&self) -> Vec<PathBuf>

Returns the actual file paths to delete for selected items. TB result items are virtual groupings — expand them to their component files.

pub fn select_all(&mut self)

pub fn select_none(&mut self) -> bool

pub fn select_name(&mut self, name: &str)

pub fn select_by_prefix(&mut self, prefix: &str) -> bool

Selects the first item whose name starts with the given prefix (case-insensitive). Returns true if an item was selected.

fn index_before_focus(current_focus: Option<usize>, forward: bool) -> usize

fn index_after_focus(current_focus: Option<usize>, forward: bool) -> usize

fn select_first_prefix_from_index( prefix_lower: &str, items: &mut [Item], start: usize, forward: bool, ) -> Option<usize>

fn select_first_prefix_match<'a>( prefix: &str, items: impl Iterator<Item = (usize, &'a mut Item)>, ) -> Option<usize>

Selects the first item in the given iterator whose name starts with the given prefix.

The prefix must be lowercase.

pub fn select_paths(&mut self, paths: Vec<PathBuf>)

fn select_position(&mut self, row: usize, col: usize, mod_shift: bool) -> bool

pub fn select_rect(&mut self, rect: Rectangle, mod_ctrl: bool, mod_shift: bool)

pub fn select_focus_id(&self) -> Option<Id>

fn select_focus_pos_opt(&self) -> Option<(usize, usize)>

fn dehighlight_all(&mut self)

pub(crate) fn select_focus_scroll(&mut self) -> Option<AbsoluteOffset>

fn rows_per_page(&self) -> usize

fn select_range_start_pos_opt(&self) -> Option<(usize, usize)>

fn select_first_pos_opt(&self) -> Option<(usize, usize)>

fn select_last_pos_opt(&self) -> Option<(usize, usize)>

fn trigger_async_decode(&mut self) -> Vec<Command>

pub fn change_location( &mut self, location: &Location, history_i_opt: Option<usize>, )

pub fn update(&mut self, message: Message, modifiers: Modifiers) -> Vec<Command>

pub(crate) const fn sort_options(&self) -> (HeadingOptions, bool, bool)

fn column_sort(&self) -> Option<Vec<(usize, &Item)>>

fn dnd_dest<'a>( &self, location: &Location, element: impl Into<Element<'a, Message>>, ) -> Element<'a, Message>

pub fn gallery_view(&self) -> Element<'_, Message>

pub fn location_view(&self) -> Element<'_, Message>

pub fn empty_view( &self, has_hidden: bool, susceptible_hidden: bool, ) -> Element<'_, Message>

pub fn grid_view( &self, ) -> (Option<Element<'static, Message>>, Element<'_, Message>, bool)

pub fn list_view( &self, ) -> (Option<Element<'static, Message>>, Element<'_, Message>, bool)

pub fn view_responsive<'a>( &'a self, key_binds: &'a HashMap<KeyBind, Action>, modifiers: &'a Modifiers, size: Size, clipboard_paste_available: bool, context_actions: &'a [ContextActionPreset], ) -> Element<'a, Message>

pub fn multi_preview_view<'a>( &'a self, mime_app_cache_opt: Option<&'a MimeAppCache>, ) -> Element<'a, Message>

pub fn view<'a>( &'a self, key_binds: &'a HashMap<KeyBind, Action>, modifiers: &'a Modifiers, clipboard_paste_available: bool, context_actions: &'a [ContextActionPreset], ) -> Element<'a, Message>

pub fn subscription(&self, preview: bool) -> Subscription<Message>

const fn format_time(&self, time: SystemTime) -> FormatTime<'_>